@@ -12,13 +12,7 @@ from torcheval.metrics.functional.classification.precision_recall_curve import (
     multiclass_precision_recall_curve,
     multilabel_precision_recall_curve,
 )
-
-
-def _riemann_integral(x: torch.Tensor, y: torch.Tensor) -> torch.Tensor:
-    """Riemann integral approximates the area of each cell with a rectangle positioned at the egde.
-    It is conventionally used rather than trapezoid approximation, which uses a rectangle positioned in the
-    center, for PRAUC"""
-    return -torch.sum((x[1:] - x[:-1]) * y[:-1])
+from torcheval.metrics.functional.tensor_utils import _riemann_integral
 
 
 @torch.inference_mode()
@@ -28,7 +22,7 @@ def binary_auprc(
     *,
     num_tasks: int = 1,
 ) -> torch.Tensor:
-    """
+    r"""
     Compute AUPRC, also called Average Precision, which is the area under the Precision-Recall Curve, for binary classification.
     Its class version is ``torcheval.metrics.BinaryAUPRC``.
 
@@ -45,7 +39,7 @@ def binary_auprc(
         target (Tensor): Tensor of ground truth labels with shape of (num_tasks, n_sample) or (n_sample, ).
         num_tasks (int):  Number of tasks that need BinaryAUPRC calculation. Default value
                     is 1. Binary AUPRC for each task will be calculated independently. Results are
-                    equivelent to calling binary_auprc for each row.
+                    equivalent to calling binary_auprc for each row.
 
     Examples::
 
@@ -80,7 +74,7 @@ def multiclass_auprc(
     *,
     average: Optional[str] = "macro",
 ) -> torch.Tensor:
-    """
+    r"""
     Compute AUPRC, also called Average Precision, which is the area under the Precision-Recall Curve, for multiclass classification.
     Its class version is ``torcheval.metrics.MulticlassAUPRC``.
 
@@ -96,6 +90,7 @@ def multiclass_auprc(
     classes are considered condition false.
 
     The results of N class multiclass auprc without an average is equivalent to binary auprc with N tasks if:
+
     1. the input is transposed, in binary classification examples are associated with columns, whereas they are associated with rows in multiclass classification.
     2. the `target` is translated from the form [1,0,1] to the form [[0,1,0], [1,0,1]]
 
@@ -157,7 +152,7 @@ def multilabel_auprc(
     *,
     average: Optional[str] = "macro",
 ) -> torch.Tensor:
-    """
+    r"""
     Compute AUPRC, also called Average Precision, which is the area under the Precision-Recall Curve, for multilabel classification.
     Its class version is ``torcheval.metrics.MultilabelAUPRC``.
 
@@ -175,6 +170,7 @@ def multilabel_auprc(
     sample, in which there may be more than 2 distinct classes but each sample must have exactly one class.
 
     The results of N label multilabel auprc without an average is equivalent to binary auprc with N tasks if:
+
     1. the `input` is transposed, in binary labelification examples are associated with columns, whereas they are associated with rows in multilabel classification.
     2. the `target` is transposed for the same reason
 
